==> ejc-technologymanage-impl-3.0.0-20220425.074720-12-sources.jar: com/ejianc/business/constructor/bean/AqbshfaEntity.java <==
package com.ejianc.business.constructor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 安全部审核方案
 * 
 * @author generator
 * 
 */
 @TableName("t_technologymanage_aqbshfa")
public class AqbshfaEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="famc")
    private String famc; // 方案名称
    @TableField(value="falx_id")
    private Long falxId; // 方案类型id
    @TableField(value="falx_name")
    private String falxName; // 方案类型
    @TableField(value="gcxmmc_id")
    private Long gcxmmcId; // 工程项目名称id
    @TableField(value="gcxmmc_name")
    private String gcxmmcName; // 工程项目名称
    @TableField(value="sgdw_id")
    private Long sgdwId; // 施工单位id
    @TableField(value="sgdw_name")
    private String sgdwName; // 施工单位
    @TableField(value="gcjd_id")
    private Long gcjdId; // 工程阶段id
    @TableField(value="gcjd_name")
    private String gcjdName; // 工程阶段
    @TableField(value="gclb_id")
    private Long gclbId; // 工程类别id
    @TableField(value="gclb_name")
    private String gclbName; // 工程类别
    @TableField(value="jglx_id")
    private Long jglxId; // 结构类型id
    @TableField(value="jglx_name")
    private String jglxName; // 结构类型
    @TableField(value="ssxjz_id")
    private Long ssxjzId; // 所属巡检组id
    @TableField(value="ssxjz_name")
    private String ssxjzName; // 所属巡检组
    @TableField(value="htkgrq")
    private Date htkgrq; // 合同开工日期
    @TableField(value="htjgrq")
    private Date htjgrq; // 合同竣工日期
    @TableField(value="jlsq")
    private Integer jlsq; // 监理审批(0:是 1：否)
    @TableField(value="tags")
    private String tags; // 分类标签
    @TableField(value="billType")
    private String billtype; // 单据类型
    @TableField(value="fileId")
    private Long fileid; // 文件id
    @TableField(value="fileName")
    private String filename; // 文件名称
    @TableField(value="fileSize")
    private Long filesize; // 文件大小
    @TableField(value="filePath")
    private String filepath; // 文件路径
    @TableField(value="onlinePath")
    private String onlinepath; // 网络路径
    @TableField(value="superviseUserId")
    private Long superviseuserid; // 管理人id
    @TableField(value="superviseUserName")
    private String superviseusername; // 管理人姓名
    @TableField(value="superviseTime")
    private Date supervisetime; // 文件上传时间
    @TableField(value="docSource")
    private Integer docsource; // 文档来源
    @TableField(value="sourceId")
    private Long sourceid; // 来源id
    @TableField(value="orgIdField")
    private String orgidfield; // 文件组织名称
    @TableField(value="projectIdField")
    private String projectidfield; // 文件项目名称
    @TableField(value="detailPageUrl")
    private String detailpageurl; // 页面地址
    @TableField(value="billCodeField")
    private String billcodefield; // 文件单据编号名称
    @TableField(value="fileType")
    private String filetype; // 文件类型
    @TableField(value="gd")
    private Integer gd; // 是否完成归档(0:是 1：否)

    public Integer getGd() {
        return gd;
    }

    public void setGd(Integer gd) {
        this.gd = gd;
    }
    public String getBilltype() {
        return billtype;
    }

    public void setBilltype(String billtype) {
        this.billtype = billtype;
    }

    public Long getFileid() {
        return fileid;
    }

    public void setFileid(Long fileid) {
        this.fileid = fileid;
    }

    public String getFilename() {
        return filename;
    }

    public void setFilename(String filename) {
        this.filename = filename;
    }

    public Long getFilesize() {
        return filesize;
    }

    public void setFilesize(Long filesize) {
        this.filesize = filesize;
    }

    public String getFilepath() {
        return filepath;
    }

    public void setFilepath(String filepath) {
        this.filepath = filepath;
    }

    public String getOnlinepath() {
        return onlinepath;
    }

    public void setOnlinepath(String onlinepath) {
        this.onlinepath = onlinepath;
    }

    public Long getSuperviseuserid() {
        return superviseuserid;
    }

    public void setSuperviseuserid(Long superviseuserid) {
        this.superviseuserid = superviseuserid;
    }

    public String getSuperviseusername() {
        return superviseusername;
    }

    public void setSuperviseusername(String superviseusername) {
        this.superviseusername = superviseusername;
    }

    public Date getSupervisetime() {
        return supervisetime;
    }

    public void setSupervisetime(Date supervisetime) {
        this.supervisetime = supervisetime;
    }

    public Integer getDocsource() {
        return docsource;
    }

    public void setDocsource(Integer docsource) {
        this.docsource = docsource;
    }

    public Long getSourceid() {
        return sourceid;
    }

    public void setSourceid(Long sourceid) {
        this.sourceid = sourceid;
    }

    public String getOrgidfield() {
        return orgidfield;
    }

    public void setOrgidfield(String orgidfield) {
        this.orgidfield = orgidfield;
    }

    public String getProjectidfield() {
        return projectidfield;
    }

    public void setProjectidfield(String projectidfield) {
        this.projectidfield = projectidfield;
    }

    public String getDetailpageurl() {
        return detailpageurl;
    }

    public void setDetailpageurl(String detailpageurl) {
        this.detailpageurl = detailpageurl;
    }

    public String getBillcodefield() {
        return billcodefield;
    }

    public void setBillcodefield(String billcodefield) {
        this.billcodefield = billcodefield;
    }

    public String getFiletype() {
        return filetype;
    }

    public void setFiletype(String filetype) {
        this.filetype = filetype;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getFamc() {
        return famc;
    }

    public void setFamc(String famc) {
        this.famc = famc;
    }
    public Long getFalxId() {
        return falxId;
    }

    public void setFalxId(Long falxId) {
        this.falxId = falxId;
    }
    public String getFalxName() {
        return falxName;
    }

    public void setFalxName(String falxName) {
        this.falxName = falxName;
    }
    public Long getGcxmmcId() {
        return gcxmmcId;
    }

    public void setGcxmmcId(Long gcxmmcId) {
        this.gcxmmcId = gcxmmcId;
    }
    public String getGcxmmcName() {
        return gcxmmcName;
    }

    public void setGcxmmcName(String gcxmmcName) {
        this.gcxmmcName = gcxmmcName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public Long getGcjdId() {
        return gcjdId;
    }

    public void setGcjdId(Long gcjdId) {
        this.gcjdId = gcjdId;
    }
    public String getGcjdName() {
        return gcjdName;
    }

    public void setGcjdName(String gcjdName) {
        this.gcjdName = gcjdName;
    }
    public Long getGclbId() {
        return gclbId;
    }

    public void setGclbId(Long gclbId) {
        this.gclbId = gclbId;
    }
    public String getGclbName() {
        return gclbName;
    }

    public void setGclbName(String gclbName) {
        this.gclbName = gclbName;
    }
    public Long getJglxId() {
        return jglxId;
    }

    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }
    public Long getSsxjzId() {
        return ssxjzId;
    }

    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getHtkgrq() {
        return htkgrq;
    }

    public void setHtkgrq(Date htkgrq) {
        this.htkgrq = htkgrq;
    }
    public Date getHtjgrq() {
        return htjgrq;
    }

    public void setHtjgrq(Date htjgrq) {
        this.htjgrq = htjgrq;
    }
    public Integer getJlsq() {
        return jlsq;
    }

    public void setJlsq(Integer jlsq) {
        this.jlsq = jlsq;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }
}

==> ejc-technologymanage-impl-3.0.0-20250929.075736-53-sources.jar: com/ejianc/business/constructor/bean/AqbshfaEntity.java <==
package com.ejianc.business.constructor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 安全部审核方案
 * 
 * @author generator
 * 
 */
 @TableName("t_technologymanage_aqbshfa")
public class AqbshfaEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="famc")
    private String famc; // 方案名称
    @TableField(value="falx_id")
    private Long falxId; // 方案类型id
    @TableField(value="falx_name")
    private String falxName; // 方案类型
    @TableField(value="gcxmmc_id")
    private Long gcxmmcId; // 工程项目名称id
    @TableField(value="gcxmmc_name")
    private String gcxmmcName; // 工程项目名称
    @TableField(value="sgdw_id")
    private Long sgdwId; // 施工单位id
    @TableField(value="sgdw_name")
    private String sgdwName; // 施工单位
    @TableField(value="gcjd_id")
    private Long gcjdId; // 工程阶段id
    @TableField(value="gcjd_name")
    private String gcjdName; // 工程阶段
    @TableField(value="gclb_id")
    private Long gclbId; // 工程类别id
    @TableField(value="gclb_name")
    private String gclbName; // 工程类别
    @TableField(value="jglx_id")
    private Long jglxId; // 结构类型id
    @TableField(value="jglx_name")
    private String jglxName; // 结构类型
    @TableField(value="ssxjz_id")
    private Long ssxjzId; // 所属巡检组id
    @TableField(value="ssxjz_name")
    private String ssxjzName; // 所属巡检组
    @TableField(value="htkgrq")
    private Date htkgrq; // 合同开工日期
    @TableField(value="htjgrq")
    private Date htjgrq; // 合同竣工日期
    @TableField(value="jlsq")
    private Integer jlsq; // 监理审批(0:是 1：否)
    @TableField(value="tags")
    private String tags; // 分类标签
    @TableField(value="billType")
    private String billtype; // 单据类型
    @TableField(value="fileId")
    private Long fileid; // 文件id
    @TableField(value="fileName")
    private String filename; // 文件名称
    @TableField(value="fileSize")
    private Long filesize; // 文件大小
    @TableField(value="filePath")
    private String filepath; // 文件路径
    @TableField(value="onlinePath")
    private String onlinepath; // 网络路径
    @TableField(value="superviseUserId")
    private Long superviseuserid; // 管理人id
    @TableField(value="superviseUserName")
    private String superviseusername; // 管理人姓名
    @TableField(value="superviseTime")
    private Date supervisetime; // 文件上传时间
    @TableField(value="docSource")
    private Integer docsource; // 文档来源
    @TableField(value="sourceId")
    private Long sourceid; // 来源id
    @TableField(value="orgIdField")
    private String orgidfield; // 文件组织名称
    @TableField(value="projectIdField")
    private String projectidfield; // 文件项目名称
    @TableField(value="detailPageUrl")
    private String detailpageurl; // 页面地址
    @TableField(value="billCodeField")
    private String billcodefield; // 文件单据编号名称
    @TableField(value="fileType")
    private String filetype; // 文件类型
    @TableField(value="gd")
    private Integer gd; // 是否完成归档(0:是 1：否)
    @TableField(value="level_type")
    private String levelType; // 安全级别
    @TableField(value="seal_type")
    private String sealType; // 用印规范

    public Integer getGd() {
        return gd;
    }

    public void setGd(Integer gd) {
        this.gd = gd;
    }
    public String getBilltype() {
        return billtype;
    }

    public void setBilltype(String billtype) {
        this.billtype = billtype;
    }

    public Long getFileid() {
        return fileid;
    }

    public void setFileid(Long fileid) {
        this.fileid = fileid;
    }

    public String getFilename() {
        return filename;
    }

    public void setFilename(String filename) {
        this.filename = filename;
    }

    public Long getFilesize() {
        return filesize;
    }

    public void setFilesize(Long filesize) {
        this.filesize = filesize;
    }

    public String getFilepath() {
        return filepath;
    }

    public void setFilepath(String filepath) {
        this.filepath = filepath;
    }

    public String getOnlinepath() {
        return onlinepath;
    }

    public void setOnlinepath(String onlinepath) {
        this.onlinepath = onlinepath;
    }

    public Long getSuperviseuserid() {
        return superviseuserid;
    }

    public void setSuperviseuserid(Long superviseuserid) {
        this.superviseuserid = superviseuserid;
    }

    public String getSuperviseusername() {
        return superviseusername;
    }

    public void setSuperviseusername(String superviseusername) {
        this.superviseusername = superviseusername;
    }

    public Date getSupervisetime() {
        return supervisetime;
    }

    public void setSupervisetime(Date supervisetime) {
        this.supervisetime = supervisetime;
    }

    public Integer getDocsource() {
        return docsource;
    }

    public void setDocsource(Integer docsource) {
        this.docsource = docsource;
    }

    public Long getSourceid() {
        return sourceid;
    }

    public void setSourceid(Long sourceid) {
        this.sourceid = sourceid;
    }

    public String getOrgidfield() {
        return orgidfield;
    }

    public void setOrgidfield(String orgidfield) {
        this.orgidfield = orgidfield;
    }

    public String getProjectidfield() {
        return projectidfield;
    }

    public void setProjectidfield(String projectidfield) {
        this.projectidfield = projectidfield;
    }

    public String getDetailpageurl() {
        return detailpageurl;
    }

    public void setDetailpageurl(String detailpageurl) {
        this.detailpageurl = detailpageurl;
    }

    public String getBillcodefield() {
        return billcodefield;
    }

    public void setBillcodefield(String billcodefield) {
        this.billcodefield = billcodefield;
    }

    public String getFiletype() {
        return filetype;
    }

    public void setFiletype(String filetype) {
        this.filetype = filetype;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getFamc() {
        return famc;
    }

    public void setFamc(String famc) {
        this.famc = famc;
    }
    public Long getFalxId() {
        return falxId;
    }

    public void setFalxId(Long falxId) {
        this.falxId = falxId;
    }
    public String getFalxName() {
        return falxName;
    }

    public void setFalxName(String falxName) {
        this.falxName = falxName;
    }
    public Long getGcxmmcId() {
        return gcxmmcId;
    }

    public void setGcxmmcId(Long gcxmmcId) {
        this.gcxmmcId = gcxmmcId;
    }
    public String getGcxmmcName() {
        return gcxmmcName;
    }

    public void setGcxmmcName(String gcxmmcName) {
        this.gcxmmcName = gcxmmcName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public Long getGcjdId() {
        return gcjdId;
    }

    public void setGcjdId(Long gcjdId) {
        this.gcjdId = gcjdId;
    }
    public String getGcjdName() {
        return gcjdName;
    }

    public void setGcjdName(String gcjdName) {
        this.gcjdName = gcjdName;
    }
    public Long getGclbId() {
        return gclbId;
    }

    public void setGclbId(Long gclbId) {
        this.gclbId = gclbId;
    }
    public String getGclbName() {
        return gclbName;
    }

    public void setGclbName(String gclbName) {
        this.gclbName = gclbName;
    }
    public Long getJglxId() {
        return jglxId;
    }

    public void setJglxId(Long jglxId) {
        this.jglxId = jglxId;
    }
    public String getJglxName() {
        return jglxName;
    }

    public void setJglxName(String jglxName) {
        this.jglxName = jglxName;
    }
    public Long getSsxjzId() {
        return ssxjzId;
    }

    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getHtkgrq() {
        return htkgrq;
    }

    public void setHtkgrq(Date htkgrq) {
        this.htkgrq = htkgrq;
    }
    public Date getHtjgrq() {
        return htjgrq;
    }

    public void setHtjgrq(Date htjgrq) {
        this.htjgrq = htjgrq;
    }
    public Integer getJlsq() {
        return jlsq;
    }

    public void setJlsq(Integer jlsq) {
        this.jlsq = jlsq;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }

    public String getLevelType() {
        return levelType;
    }

    public void setLevelType(String levelType) {
        this.levelType = levelType;
    }

    public String getSealType() {
        return sealType;
    }

    public void setSealType(String sealType) {
        this.sealType = sealType;
    }
}
